@@ -118,12 +118,28 @@ import aws_cdk.aws_sns
 import aws_cdk.core
 
 
-class SnsToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-sns-lambda.SnsToLambda"):
+class SnsToLambda(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-sns-lambda.SnsToLambda",
+):
     """
     summary:
     :summary:: The SnsToLambda class.
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, deploy_lambda: bool, enable_encryption: typing.Optional[bool]=None, encryption_key: typing.Optional[aws_cdk.aws_kms.Key]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Any=None, topic_props: typing.Any=None) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        deploy_lambda: bool,
+        enable_encryption: typing.Optional[bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        lambda_function_props: typing.Any = None,
+        topic_props: typing.Any = None,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
@@ -141,7 +157,14 @@ class SnsToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@a
         summary:
         :summary:: Constructs a new instance of the LambdaToSns class.
         """
-        props = SnsToLambdaProps(deploy_lambda=deploy_lambda, enable_encryption=enable_encryption, encryption_key=encryption_key, existing_lambda_obj=existing_lambda_obj, lambda_function_props=lambda_function_props, topic_props=topic_props)
+        props = SnsToLambdaProps(
+            deploy_lambda=deploy_lambda,
+            enable_encryption=enable_encryption,
+            encryption_key=encryption_key,
+            existing_lambda_obj=existing_lambda_obj,
+            lambda_function_props=lambda_function_props,
+            topic_props=topic_props,
+        )
 
         jsii.create(SnsToLambda, self, [scope, id, props])
 
@@ -156,9 +179,29 @@ class SnsToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@a
         return jsii.get(self, "snsTopic")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-sns-lambda.SnsToLambdaProps", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'enable_encryption': 'enableEncryption', 'encryption_key': 'encryptionKey', 'existing_lambda_obj': 'existingLambdaObj', 'lambda_function_props': 'lambdaFunctionProps', 'topic_props': 'topicProps'})
-class SnsToLambdaProps():
-    def __init__(self, *, deploy_lambda: bool, enable_encryption: typing.Optional[bool]=None, encryption_key: typing.Optional[aws_cdk.aws_kms.Key]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Any=None, topic_props: typing.Any=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-sns-lambda.SnsToLambdaProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "deploy_lambda": "deployLambda",
+        "enable_encryption": "enableEncryption",
+        "encryption_key": "encryptionKey",
+        "existing_lambda_obj": "existingLambdaObj",
+        "lambda_function_props": "lambdaFunctionProps",
+        "topic_props": "topicProps",
+    },
+)
+class SnsToLambdaProps:
+    def __init__(
+        self,
+        *,
+        deploy_lambda: bool,
+        enable_encryption: typing.Optional[bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        lambda_function_props: typing.Any = None,
+        topic_props: typing.Any = None,
+    ) -> None:
         """
         :param deploy_lambda: Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the ``existingLambdaObj`` property. Default: - true
         :param enable_encryption: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
@@ -171,13 +214,18 @@ class SnsToLambdaProps():
         :summary:: The properties for the SnsToLambda class.
         """
         self._values = {
-            'deploy_lambda': deploy_lambda,
+            "deploy_lambda": deploy_lambda,
         }
-        if enable_encryption is not None: self._values["enable_encryption"] = enable_encryption
-        if encryption_key is not None: self._values["encryption_key"] = encryption_key
-        if existing_lambda_obj is not None: self._values["existing_lambda_obj"] = existing_lambda_obj
-        if lambda_function_props is not None: self._values["lambda_function_props"] = lambda_function_props
-        if topic_props is not None: self._values["topic_props"] = topic_props
+        if enable_encryption is not None:
+            self._values["enable_encryption"] = enable_encryption
+        if encryption_key is not None:
+            self._values["encryption_key"] = encryption_key
+        if existing_lambda_obj is not None:
+            self._values["existing_lambda_obj"] = existing_lambda_obj
+        if lambda_function_props is not None:
+            self._values["lambda_function_props"] = lambda_function_props
+        if topic_props is not None:
+            self._values["topic_props"] = topic_props
 
     @builtins.property
     def deploy_lambda(self) -> bool:
@@ -188,7 +236,7 @@ class SnsToLambdaProps():
         default
         :default: - true
         """
-        return self._values.get('deploy_lambda')
+        return self._values.get("deploy_lambda")
 
     @builtins.property
     def enable_encryption(self) -> typing.Optional[bool]:
@@ -200,7 +248,7 @@ class SnsToLambdaProps():
         default
         :default: - true (encryption enabled, managed by this CDK app).
         """
-        return self._values.get('enable_encryption')
+        return self._values.get("enable_encryption")
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
@@ -209,7 +257,7 @@ class SnsToLambdaProps():
         default
         :default: - not specified.
         """
-        return self._values.get('encryption_key')
+        return self._values.get("encryption_key")
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -220,7 +268,7 @@ class SnsToLambdaProps():
         default
         :default: - None
         """
-        return self._values.get('existing_lambda_obj')
+        return self._values.get("existing_lambda_obj")
 
     @builtins.property
     def lambda_function_props(self) -> typing.Any:
@@ -231,7 +279,7 @@ class SnsToLambdaProps():
         default
         :default: - Default properties are used.
         """
-        return self._values.get('lambda_function_props')
+        return self._values.get("lambda_function_props")
 
     @builtins.property
     def topic_props(self) -> typing.Any:
@@ -240,7 +288,7 @@ class SnsToLambdaProps():
         default
         :default: - Default properties are used.
         """
-        return self._values.get('topic_props')
+        return self._values.get("topic_props")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -249,7 +297,9 @@ class SnsToLambdaProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'SnsToLambdaProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "SnsToLambdaProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
